@@ -28,4 +28,6 @@ JAX_AVAILABLE = False
 
 
 # File Names
-SYS_OUTPUT_INFO_FILENAME = "sys_output_infos.json"
\ No newline at end of file
+SYS_OUTPUT_INFO_FILENAME = "system_analysis.json"
+
+
