@@ -3,5 +3,5 @@ from .loader import get_loader
 
 from . import text_classification
 from . import named_entity_recognition
-from . import qa_squad
-from . import text_summarization
\ No newline at end of file
+from . import extractive_qa
+from . import summarization
\ No newline at end of file
