@@ -4,7 +4,8 @@ import json
 from enum import Enum
 from io import StringIO
 import csv
-from explainaboard.constants import FileType, Source, TaskType
+from explainaboard.constants import FileType, Source
+from explainaboard.tasks import TaskType
 
 JSON = t.Union[str, int, float, bool, None, t.Mapping[str, 'JSON'], t.List['JSON']] # type: ignore
 
