@@ -1,6 +1,6 @@
 from typing import Iterable
 from explainaboard import feature
-from explainaboard.constants import TaskType
+from explainaboard.tasks import TaskType
 from explainaboard.processors.processor import Processor
 from explainaboard.processors.processor_registry import register_processor
 from explainaboard.builders.summarization import SummExplainaboardBuilder
