@@ -34,7 +34,7 @@ _task_categories: List[TaskCategory] = [
                      Task("machine-translation"),
                      Task("sentence-splitting-fusion"),
                      Task(TaskType.summarization, True, [
-                          "blue", "rouge1", "rouge2", "rougel"])
+                          "bleu", "rouge1", "rouge2", "rougel"])
                  ]),
     TaskCategory("text-classification", "predicting a class index or boolean value",
                  [Task(TaskType.text_classification, True, ["F1score", "Accuracy"])]),
