@@ -22,7 +22,7 @@ class TestNER(unittest.TestCase):
         #self.assertEqual(len(processor._features), 4)
 
         analysis = processor.process()
-        analysis.write_to_directory("./")
+        # analysis.write_to_directory("./")
         #print(analysis)
         self.assertIsNotNone(analysis.results.fine_grained)
         self.assertGreater(len(analysis.results.overall), 0)
